@@ -1,5 +1,4 @@
 package HTML::Template::Compiled::Compiler;
-# $Id: Compiler.pm 1161 2012-05-05 14:00:22Z tinita $
 use strict;
 use warnings;
 use Data::Dumper;
@@ -8,7 +7,7 @@ use HTML::Template::Compiled::Expression qw(:expressions);
 use HTML::Template::Compiled::Utils qw(:walkpath);
 use File::Basename qw(dirname);
 
-our $VERSION = '0.20';
+our $VERSION = '1.001_002'; # VERSION
 
 our $DISABLE_NEW_ALIAS = 0;
 
@@ -1140,10 +1139,11 @@ EOM
             my $var = $attr->{NAME};
             $var = '' unless defined $var;
             #print STDERR "============ IF ($text)\n";
-            $code .= "\}" . ($tname eq 'WITH' ? "\}" : '') . qq{\n};
+            $code .= "\}" ;
             if ($self->get_global_vars && $tname eq 'WITH') {
-                $code .= $indent . qq#\$t->popGlobalstack;\n#;
+                $code .= qq{\n} . $indent . qq#\$t->popGlobalstack;\n#;
             }
+            $code .= ($tname eq 'WITH' ? "\}" : '') . qq{\n};
         }
 
         # --------- / TMPL_SWITCH
@@ -1163,12 +1163,11 @@ EOM
             if ($self->get_use_query) {
                 pop @$info_stack;
             }
-            $code .= "\}\n\} # end loop\n";
+            $code .= "\}";
             if ($self->get_global_vars) {
-            $code .= <<"EOM";
-${indent}\$t->popGlobalstack;
-EOM
+                $code .= qq{\n} . $indent . qq#\$t->popGlobalstack;\n#;
             }
+            $code .= "\} # end loop\n";
         }
         elsif ($tname eq T_WRAPPER) {
             $code .= $wrapped[-1];
