@@ -1,40 +1,49 @@
 package HTML::Template::Compiled::Compiler::Classic;
-# $Id: Classic.pm,v 1.8 2006/10/11 20:52:50 tinita Exp $
 use strict;
 use warnings;
-our $VERSION = "0.01";
+our $VERSION = '1.001_002'; # VERSION
 
 use base 'HTML::Template::Compiled::Compiler';
 
 sub parse_var {
     my ( $self, $t, %args ) = @_;
     my $context = $args{context};
-    # only allow '.', '/', '+', '-' and '_'
     if (!$t->validate_var($args{var})) {
         $t->get_parser->_error_wrong_tag_syntax(
-            $context->get_file, $context->get_line, "", $args{var}
+            {
+                fname => $context->get_file,
+                line  => $context->get_line,
+                token => "",
+            },
+            $args{var}
         );
     }
     my %loop_context = (
         __index__   => '$__ix__',
         __counter__ => '$__ix__+1',
         __first__   => '$__ix__ == $[',
-        __last__    => '$__ix__ == $size',
+        __last__    => '$__ix__ == $__size__',
         __odd__     => '!($__ix__ & 1)',
-        __inner__   => '$__ix__ != $[ && $__ix__ != $size',
+        __even__    => '($__ix__ & 1)',
+        __inner__   => '$__ix__ != $[ && $__ix__ != $__size__',
+        __outer__   => '$__ix__ == $[ || $__ix__ == $__size__',
+        __break__   => '$__break__',
+        __filename__ => '$t->get_file',
+        __filenameshort__ => '$t->get_filename',
+        __wrapped__ => '$args->{wrapped}',
     );
 
     if ( $t->get_loop_context && $args{var} =~ m/^__(\w+)__$/ ) {
         my $lc = $loop_context{ lc $args{var} };
         return $lc;
     }
+    my $var = $t->get_case_sensitive ? $args{var} : lc $args{var};
     if ($t->get_global_vars & 1) {
         my $varstr =
-            "\$t->_get_var_global_sub(" . '$P,$$C,0,'."[undef,'$args{var}'])";
+            "\$t->_get_var_global_sub(" . '$P,$$C,0,'."[undef,'$var'])";
         return $varstr;
     }
     else {
-        my $var = $args{var};
         $var =~ s/\\/\\\\/g;
         $var =~ s/'/\\'/g;
         my $varstr = '$$C->{' . "'$var'" . '}';
