@@ -1,12 +1,11 @@
 package HTML::Template::Compiled::Expr;
-# $Id: Expr.pm 1050 2008-06-16 20:27:20Z tinita $
 use strict;
 use warnings;
 use Carp qw(croak carp);
 #use HTML::Template::Compiled::Expression qw(:expressions);
 use HTML::Template::Compiled;
 use Parse::RecDescent;
-our $VERSION = '0.06';
+our $VERSION = '1.001_002'; # VERSION
 
 my $re = qr# (?:
     \b(?:eq | ne | ge | le | gt | lt )\b
@@ -239,10 +238,14 @@ HTML::Template::Compiled::Expr - Expressions for HTC
 
 =head1 DESCRIPTION
 
-Works like L<HTML::Template::Expr>, with the additional possibility
-to do method calls with parameters.
+The expressions work like in L<HTML::Template::Expr>, with some additional
+possibilities regarding object method calls and arbitrary data structures.
 
-See the option C<use_expressions> in L<HTML::Template::Compiled/"OPTIONS">
+Different from L<HTML::Template::Expr>, you don't use it as the module
+class, but you activate it by passing the option C<use_expressions> with
+a true value.
+
+See C<use_expressions> in L<HTML::Template::Compiled/"OPTIONS">
 
 =cut
 
