@@ -1,5 +1,4 @@
 package HTML::Template::Compiled::Token;
-# $Id: Token.pm,v 1.8 2006/10/20 19:46:59 tinita Exp $
 use strict;
 use warnings;
 use Carp qw(croak carp);
@@ -9,7 +8,7 @@ our %EXPORT_TAGS = (
     tagtypes => [qw(&NO_TAG &OPENING_TAG &CLOSING_TAG)],
 );
 
-our $VERSION = '0.02';
+our $VERSION = '1.001_002'; # VERSION
 
 use constant ATTR_TEXT       => 0;
 use constant ATTR_LINE       => 1;
@@ -85,7 +84,7 @@ __END__
 
 =head1 NAME
 
-HTML::Template::Compiled::Token
+HTML::Template::Compiled::Token - a compiled HTML template token
 
 =cut
 
