@@ -1,9 +1,9 @@
 package HTML::Template::Compiled::Utils;
-# $Id: Utils.pm,v 1.19 2007/08/13 11:12:40 tinita Exp $
-$VERSION = "0.05";
+our $VERSION = '1.001_002'; # VERSION
 use strict;
 use warnings;
 use Data::Dumper qw(Dumper);
+use Digest::MD5;
 
 use base 'Exporter';
 use vars qw/@EXPORT_OK %EXPORT_TAGS/;
@@ -28,13 +28,6 @@ use constant PATH_DEREF => 2;
 use constant PATH_FORMATTER => 3;
 use constant PATH_ARRAY => 4;
 
-my $digest_md5 = 0;
-eval {
-    require Digest::MD5;
-};
-unless ($@) {
-    $digest_md5 = 1;
-}
 
 =pod
 
@@ -72,12 +65,13 @@ otherwise returns the empty string.
 
 =cut
 
+use Encode ();
 sub md5 {
     my ($text) = @_;
-    if ($digest_md5) {
-        return Digest::MD5::md5_base64($text);
+    if (Encode::is_utf8($text)) {
+        $text = Encode::encode_utf8($text);
     }
-    return '';
+    return Digest::MD5::md5_base64($text);
 }
 
 sub stack {
@@ -161,6 +155,7 @@ sub escape_html_all {
     return $_[0] unless defined $_[0];
     # hopefully encode_entities() works correct
     # and doesn't change its arg when called in scalar context
+    require HTML::Entities;
     return HTML::Entities::encode_entities($_[0]);
 }
 
@@ -172,11 +167,9 @@ URI-escapes the input string and returns it;
 
 =cut
 
-eval { require Encode };
-my $encode = $@ ? 0 : 1;
 sub escape_uri {
     # if we want to use utf8 we require Encode.pm to be installed
-    my $x = ($encode and Encode::is_utf8($_[0]))
+    my $x = (Encode::is_utf8($_[0]))
         ? URI::Escape::uri_escape_utf8( $_[0] )
         : URI::Escape::uri_escape( $_[0] );
     return $x;
@@ -193,7 +186,25 @@ JavaScript-escapes the input string and returns it;
 sub escape_js {
     my ($var) = @_;
     return $var unless defined $var;
-    $var =~ s/(["'])/\\$1/g;
+    $var =~ s/(["'\\])/\\$1/g;
+    $var =~ s/\r/\\r/g;
+    $var =~ s/\n/\\n/g;
+    return $var;
+}
+
+=head2 escape_ijson
+
+  my $escaped_js = escape_ijson($raw_js);
+
+JavaScript-escapes the input string except for the apostrophe and returns it,
+so it can be used within a JSON element.
+
+=cut
+
+sub escape_ijson {
+    my ($var) = @_;
+    return $var unless defined $var;
+    $var =~ s/([\\"])/\\$1/g;
     $var =~ s/\r/\\r/g;
     $var =~ s/\n/\\n/g;
     return $var;
